/*
 * Copyright 2003 - 2011 The eFaps Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Revision:        $Rev: 8903 $
 * Last Changed:    $Date: 2013-02-20 15:54:17 -0500 (Wed, 20 Feb 2013) $
 * Last Changed By: $Author: jan@moxter.net $
 */

package org.efaps.wikiutil.wom.element.text;

import org.apache.commons.lang3.builder.ToStringBuilder;
import org.efaps.wikiutil.wom.element.AbstractLineElement;

/**
 * An internal link of a text element.
 *
 * @author The eFaps Team
 * @version $Id: AbstractInternalLink.java 8903 2013-02-20 20:54:17Z jan@moxter.net $
 */
public abstract class AbstractInternalLink
    extends AbstractLineElement
{

    /**
     * Defines the link string of the internal link.
     *
     * @see #InternalLink(String)
     * @see #getLink()
     */
    private final String link;

    /**
     * Initializes the {@link #link}.
     *
     * @param _link     link
     */
    public AbstractInternalLink(final CharSequence _link)
    {
        this.link = _link.toString();
    }

    /**
     * Returns the internal {@link #link}.
     *
     * @return link
     * @see #link
     */
    public String getLink()
    {
        return this.link;
    }


    /**
     * Returns the string representation of this class including the related
     * {@link #link}.
     *
     * @return string representation of this class
     */
    @Override
    public String toString()
    {
        return new ToStringBuilder(this)
            .appendSuper(super.toString())
            .append("link", this.link)
            .toString();
    }
}
